==> qiho-center-api-2.3.71-20200312.102159-5-sources.jar: com/qiho/center/api/dto/ordertmp/OrderTmpDetailDto.java <==
package com.qiho.center.api.dto.ordertmp;

import com.qiho.center.api.dto.discount.OrderDiscountDto;

import java.util.List;

/** 临时订单所有的字段 Dto
 * @author chensong
 * @create 2018-05-10 11:54
 **/
public class OrderTmpDetailDto extends OrderTmpDto {



    /** 商品简称 */
    private String  itemShortName;

    /** 商品图片 */
    private String  image;

    /** sku名称 */
    private String  skuName;

    /** 下单URL */
    private String  url;

    /** ip地址 */
    private String  ip;

    /** 用户代理，包含用户操作系统及浏览器版本等信息 */
    private String  userAgent;

    /** 售价，单位：分 */
    private Integer sellingPrice;

    /** 订单原始金额 */
    private Integer originalPrice;

    /** 商品件数 */
    private Integer quantity;

    /** 支付方式 */
    private String  payType;

    /** 订单金额 */
    private Integer orderAmt;

    /** 省 */
    private String  province;

    /** 市 */
    private String  city;

    /** 区 */
    private String  district;

    /** 详细地址 */
    private String  address;

    /** 用户留言 */
    private String  message;

    /** tuiaId */
    private String  tuiaId;

    /** 页面停留时间 */
    private Long remainTime;

    /** 商品成本 */
    private Integer itemCost;

    /** 订单原始金额 */
    private Integer orderOriginalAmt;

    /** 快递派送时间*/
    private String sendTime;

    /** ssjx来源参数 */
    private String sid;

    /** 前端传的tokenId */
    private String tokenId;

    /** 皮肤id */
    private Long skinId;

    /** appId */
    private Long appId;

    /** A/B test实验code */
    private String planCode;

    /** 推啊用户id */
    private String tuiaCid;

    /** skuId */
    private Long skuId;

    /** 命中的防作弊信息 */
    private List<String> anticheatRules;

    /** 商家名称 */
    private String merchantName;

    /**
     * 下单用户Id
     */
    private Long userId;

    /**
     * 用户身份证号
     */
    private String idCard;

    /** 优惠信息 */
    private OrderDiscountDto orderDiscountDto;

    public OrderDiscountDto getOrderDiscountDto() {
        return orderDiscountDto;
    }

    public void setOrderDiscountDto(OrderDiscountDto orderDiscountDto) {
        this.orderDiscountDto = orderDiscountDto;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getMerchantName() {
        return merchantName;
    }

    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName;
    }

    public List<String> getAnticheatRules() {
        return anticheatRules;
    }

    public void setAnticheatRules(List<String> anticheatRules) {
        this.anticheatRules = anticheatRules;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public String getItemShortName() {
        return itemShortName;
    }

    public void setItemShortName(String itemShortName) {
        this.itemShortName = itemShortName;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    public Integer getSellingPrice() {
        return sellingPrice;
    }

    public void setSellingPrice(Integer sellingPrice) {
        this.sellingPrice = sellingPrice;
    }

    public Integer getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(Integer originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public Integer getOrderAmt() {
        return orderAmt;
    }

    public void setOrderAmt(Integer orderAmt) {
        this.orderAmt = orderAmt;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getTuiaId() {
        return tuiaId;
    }

    public void setTuiaId(String tuiaId) {
        this.tuiaId = tuiaId;
    }

    public Long getRemainTime() {
        return remainTime;
    }

    public void setRemainTime(Long remainTime) {
        this.remainTime = remainTime;
    }

    public Integer getItemCost() {
        return itemCost;
    }

    public void setItemCost(Integer itemCost) {
        this.itemCost = itemCost;
    }

    public Integer getOrderOriginalAmt() {
        return orderOriginalAmt;
    }

    public void setOrderOriginalAmt(Integer orderOriginalAmt) {
        this.orderOriginalAmt = orderOriginalAmt;
    }

    public String getSendTime() {
        return sendTime;
    }

    public void setSendTime(String sendTime) {
        this.sendTime = sendTime;
    }

    public String getSid() {
        return sid;
    }

    public void setSid(String sid) {
        this.sid = sid;
    }

    public String getTokenId() {
        return tokenId;
    }

    public void setTokenId(String tokenId) {
        this.tokenId = tokenId;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getPlanCode() {
        return planCode;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }

    public String getTuiaCid() {
        return tuiaCid;
    }

    public void setTuiaCid(String tuiaCid) {
        this.tuiaCid = tuiaCid;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }
}

==> qiho-center-api-2.5.9-20200810.061007-2-sources.jar: com/qiho/center/api/dto/ordertmp/OrderTmpDetailDto.java <==
package com.qiho.center.api.dto.ordertmp;

import com.qiho.center.api.dto.discount.OrderDiscountDto;

import java.util.List;

/** 临时订单所有的字段 Dto
 * @author chensong
 * @create 2018-05-10 11:54
 **/
public class OrderTmpDetailDto extends OrderTmpDto {



    /** 商品简称 */
    private String  itemShortName;

    /** 商品图片 */
    private String  image;

    /** sku名称 */
    private String  skuName;

    /** 下单URL */
    private String  url;

    /** ip地址 */
    private String  ip;

    /** 用户代理，包含用户操作系统及浏览器版本等信息 */
    private String  userAgent;

    /** 售价，单位：分 */
    private Integer sellingPrice;

    /** 订单原始金额 */
    private Integer originalPrice;

    /** 商品件数 */
    private Integer quantity;

    /** 支付方式 */
    private String  payType;

    /** 订单金额 */
    private Integer orderAmt;

    /** 省 */
    private String  province;

    /** 市 */
    private String  city;

    /** 区 */
    private String  district;

    /** 详细地址 */
    private String  address;

    /** 用户留言 */
    private String  message;

    /** tuiaId */
    private String  tuiaId;

    /** 页面停留时间 */
    private Long remainTime;

    /** 商品成本 */
    private Integer itemCost;

    /** 订单原始金额 */
    private Integer orderOriginalAmt;

    /** 快递派送时间*/
    private String sendTime;

    /** ssjx来源参数 */
    private String sid;

    /** 前端传的tokenId */
    private String tokenId;

    /** 皮肤id */
    private Long skinId;

    /** appId */
    private Long appId;

    /** A/B test实验code */
    private String planCode;

    /** 推啊用户id */
    private String tuiaCid;

    /** skuId */
    private Long skuId;

    /** 命中的防作弊信息 */
    private List<String> anticheatRules;

    /** 商家名称 */
    private String merchantName;

    /**
     * 下单用户Id
     */
    private Long userId;

    /**
     * 用户身份证号
     */
    private String idCard;

    /**
     * 下单的页面ID
     */
    private Long pageId;

    /**
     * 下单的页面表单顺序
     */
    private Integer formNumber;

    /**
     * 订单扩展字段
     */
    private String extJson;

    /** 优惠信息 */
    private OrderDiscountDto orderDiscountDto;

    public OrderDiscountDto getOrderDiscountDto() {
        return orderDiscountDto;
    }

    public void setOrderDiscountDto(OrderDiscountDto orderDiscountDto) {
        this.orderDiscountDto = orderDiscountDto;
    }

    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }

    public String getMerchantName() {
        return merchantName;
    }

    public void setMerchantName(String merchantName) {
        this.merchantName = merchantName;
    }

    public List<String> getAnticheatRules() {
        return anticheatRules;
    }

    public void setAnticheatRules(List<String> anticheatRules) {
        this.anticheatRules = anticheatRules;
    }

    public Long getSkuId() {
        return skuId;
    }

    public void setSkuId(Long skuId) {
        this.skuId = skuId;
    }

    public String getItemShortName() {
        return itemShortName;
    }

    public void setItemShortName(String itemShortName) {
        this.itemShortName = itemShortName;
    }

    public String getImage() {
        return image;
    }

    public void setImage(String image) {
        this.image = image;
    }

    public String getSkuName() {
        return skuName;
    }

    public void setSkuName(String skuName) {
        this.skuName = skuName;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getIp() {
        return ip;
    }

    public void setIp(String ip) {
        this.ip = ip;
    }

    public String getUserAgent() {
        return userAgent;
    }

    public void setUserAgent(String userAgent) {
        this.userAgent = userAgent;
    }

    public Integer getSellingPrice() {
        return sellingPrice;
    }

    public void setSellingPrice(Integer sellingPrice) {
        this.sellingPrice = sellingPrice;
    }

    public Integer getOriginalPrice() {
        return originalPrice;
    }

    public void setOriginalPrice(Integer originalPrice) {
        this.originalPrice = originalPrice;
    }

    public Integer getQuantity() {
        return quantity;
    }

    public void setQuantity(Integer quantity) {
        this.quantity = quantity;
    }

    public String getPayType() {
        return payType;
    }

    public void setPayType(String payType) {
        this.payType = payType;
    }

    public Integer getOrderAmt() {
        return orderAmt;
    }

    public void setOrderAmt(Integer orderAmt) {
        this.orderAmt = orderAmt;
    }

    public String getProvince() {
        return province;
    }

    public void setProvince(String province) {
        this.province = province;
    }

    public String getCity() {
        return city;
    }

    public void setCity(String city) {
        this.city = city;
    }

    public String getDistrict() {
        return district;
    }

    public void setDistrict(String district) {
        this.district = district;
    }

    public String getAddress() {
        return address;
    }

    public void setAddress(String address) {
        this.address = address;
    }

    public String getMessage() {
        return message;
    }

    public void setMessage(String message) {
        this.message = message;
    }

    public String getTuiaId() {
        return tuiaId;
    }

    public void setTuiaId(String tuiaId) {
        this.tuiaId = tuiaId;
    }

    public Long getRemainTime() {
        return remainTime;
    }

    public void setRemainTime(Long remainTime) {
        this.remainTime = remainTime;
    }

    public Integer getItemCost() {
        return itemCost;
    }

    public void setItemCost(Integer itemCost) {
        this.itemCost = itemCost;
    }

    public Integer getOrderOriginalAmt() {
        return orderOriginalAmt;
    }

    public void setOrderOriginalAmt(Integer orderOriginalAmt) {
        this.orderOriginalAmt = orderOriginalAmt;
    }

    public String getSendTime() {
        return sendTime;
    }

    public void setSendTime(String sendTime) {
        this.sendTime = sendTime;
    }

    public String getSid() {
        return sid;
    }

    public void setSid(String sid) {
        this.sid = sid;
    }

    public String getTokenId() {
        return tokenId;
    }

    public void setTokenId(String tokenId) {
        this.tokenId = tokenId;
    }

    public Long getSkinId() {
        return skinId;
    }

    public void setSkinId(Long skinId) {
        this.skinId = skinId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getPlanCode() {
        return planCode;
    }

    public void setPlanCode(String planCode) {
        this.planCode = planCode;
    }

    public String getTuiaCid() {
        return tuiaCid;
    }

    public void setTuiaCid(String tuiaCid) {
        this.tuiaCid = tuiaCid;
    }

    public String getIdCard() {
        return idCard;
    }

    public void setIdCard(String idCard) {
        this.idCard = idCard;
    }

    public Long getPageId() {
        return pageId;
    }

    public void setPageId(Long pageId) {
        this.pageId = pageId;
    }

    public Integer getFormNumber() {
        return formNumber;
    }

    public void setFormNumber(Integer formNumber) {
        this.formNumber = formNumber;
    }

    public String getExtJson() {
        return extJson;
    }

    public void setExtJson(String extJson) {
        this.extJson = extJson;
    }
}
